/**
 * This script finds short blank gaps or overlaps between events
 * on the first selected track. 
 * 
 * Written By: John H. Meyer
 * Date: December 2, 2003
 *
 **/

import System;
import System.IO;
import System.Windows.Forms;
import Sony.Vegas;

// Change this line if you want a different threshold

var Gap : Double = new Timecode("00:00:00:3").ToMilliseconds(); // 3 Frames

var lastevnt : TrackEvent;
var MyMarker : Marker;        // Global function used in main program and in function
var evnt : TrackEvent;
var trackEnum : Enumerator; 

try {

    var dirty = 0;
    var track = FindSelectedTrack(); //Use this function to find the first selected track.  

    //Go through the list of Events
    var eventEnum = new Enumerator(track.Events);
    var lastevnt = TrackEvent(eventEnum.item()); //initialize lastevent variable

    while (!eventEnum.atEnd() ) {
      evnt = TrackEvent( eventEnum.item() );

      var test1 = evnt.Start.ToMilliseconds();  
      var test2 = lastevnt.Start.ToMilliseconds() + lastevnt.Length.ToMilliseconds();

      // To only test for gaps only, use the first line below instead
//    if (    ( (test1 - test2) > 0.05 )  && ( (test1 - test2) < Gap )    ) {            

      if ( ( Math.abs(test1 - test2) > 0.05 )  && (Math.abs(test1 - test2) < Gap)  )  {


          if (!MarkerExist(test1) ) {
            MyMarker = new Marker(evnt.Start);
            Vegas.Project.Markers.Add(MyMarker);
            MyMarker.Label = "";
          }
           
          if (test1 > test2) {
            MyMarker.Label = MyMarker.Label + "GAP********";
          }
          else {
            MyMarker.Label = MyMarker.Label + "OVERLAP****";
          }
          dirty = 1;
        }

      lastevnt = evnt;

      eventEnum.moveNext();

    }  // End While eventEnum

    if (dirty == 1) {
        Vegas.UpdateUI();  
        MessageBox.Show("Gaps and/or overlaps were found.","Completed",MessageBoxButtons.OK,MessageBoxIcon.Information);
    }

} catch (e) {
    MessageBox.Show(e);
}


function FindSelectedTrack() : Track {
  trackEnum = new Enumerator(Vegas.Project.Tracks);
  while (!trackEnum.atEnd()) {
    var track : Track = Track(trackEnum.item());

    if (track.Selected) {
      return track;
    }
    trackEnum.moveNext();
  }
  return null;
}


function MarkerExist (dStart) : boolean {

  var markerEnum = new Enumerator(Vegas.Project.Markers);

  while (!markerEnum.atEnd()) {
    MyMarker = markerEnum.item();                    // MyMarker is a global function in this project
    var MarkerStart = MyMarker.Position.ToMilliseconds();

    if ( dStart ==  MarkerStart ) {
      return 1;
    }

  markerEnum.moveNext();

  } // End while markerEnum

  return 0;
}
