/*
 * Copyright (c) 2004, Folding Rain Filmworks Inc.
 *
 * author: Joe Howes (joeh@guild1.com)
 *
 * I wrote this script while working on the making-of documentary
 * for The Libertine.  We had a Final Cut rig and a Vegas rig and
 * not a lot of time so I had my assistant doing L&C on the Final
 * Cut rig while I edited in Vegas.  We would copy over captures
 * with a program I wrote that would just give them a ".mov" 
 * extension.  The problem is that Quicktimes captured by FCP 
 * have video that is 10 frames front-synced from the audio when 
 * brought into Vegas.  This script corrects that.
 * 
 * NOTE:  This project was a PAL project.  If you're having the
 * same problem with an NTSC project, the phase discrepancy might
 * be different, so figure out what that is and make the appropriate
 * change to the global variable "adjust" below.
 *
 * USAGE:
 * Select one or more events to adjust.  You only need to select
 * either the video OR the audio of the group, not both -- the 
 * script looks through all selected groups and slips the video 
 * only.
 *
 * v1.0: Aug. 08, 2004
 */

import System.Windows.Forms;
import System.Collections;
import Sony.Vegas;

/**
 * The Quicktime video is 10 frames out.
 * NOTE:  This was a PAL project, so the adjustment for an NTSC event 
 * may be different...just change this timecode to make that adjustment.
 */
var adjust:Timecode = new Timecode("00:00:00,10");

try
{
	var done:Boolean = false;
	
	// Search all groups
	for (var grp in Vegas.Project.Groups) 
	{
		// Only adjust if this is one video / one audio and one of
		// them is selected
		var doIt:Boolean = false;
		var videoEvent:TrackEvent = null;
		var audioEvent:TrackEvent = null;
		
		// Look at all the events in the group
		for (var evt in grp)
		{
			if (evt.Selected)
			{
				doIt = true;				
			}
			if (evt.MediaType == MediaType.Video)
			{
				videoEvent = evt;
			}
			else if (evt.MediaType == MediaType.Audio)
			{
				audioEvent = evt;
			}
		}
		
		// If none of the members are selected, skip this group
		if (!doIt)
		{
			continue;
		}
		
		// If the group is not a pair or is a pair of video or a pair of audio
		// tracks, notify
		if (grp.Count != 2 || videoEvent == null || audioEvent == null)
		{
			throw("Only select video/audio event pairs.");
		}
		
		// Now we have a video/audio event pair, slip the video back to rephase it
		done = true;		
		rephaseVideo(videoEvent);
	}
	
	Vegas.UpdateUI();
  
	if (!done)
	{
		throw("No audio tracks were rephased.");
	}
} 
catch (e) 
{
	MessageBox.Show(e, "NOTICE");
}

/**
 * To rephase the video, we just slip it back a number fo frames.
 */
function rephaseVideo(evt:TrackEvent)
{
	var newStart:Timecode = new Timecode("00:00:00,00");
	newStart = evt.Start - adjust;
	evt.AdjustStartLength(newStart, evt.Length, true);
	evt.Start = evt.Start + adjust;
}
