/**
 * Script:      RegionsToChapters.js
 * Description: This script will add chapter markers at the beginning
 *              of all the regions. It uses the region label if there
 *              is one. Otherwise it makes one up using the word
 *              Chapter + an incrmental number.
 *
 * Written By:  Johnny (Roy) Rofrano http://users.rcn.com/rofrano
 * 
 * History:
 * 03/22/2004 - (JR) Original program
 * 
 **/

import System.Windows.Forms;
import Sony.Vegas;

try 
{
	var newMarker : Marker;		// new marker to place
	var chapterNumber = 1;		// next chapter number

	var regionEnum = new Enumerator(Vegas.Project.Regions);
	while (!regionEnum.atEnd()) 
	{
		var region : Region = Region(regionEnum.item());
		
		// Check to see if there is a marker already
		var newMarker = FindMarkerAt(region.Position);
		if (null == newMarker)
		{
			// Put a marker at the start point		
			newMarker = new Marker(region.Position);
			Vegas.Project.Markers.Add(newMarker);
		}
		
		// Label the marker the same as the region. If the region
		// has no label, make one up using Chapter + number
		if (region.Label != "")
		{
			newMarker.Label = region.Label;
		}
		else
		{
			newMarker.Label = "Chapter " + chapterNumber;
		}
		// increment chapter so it is always the Nth marker
		chapterNumber++;
		
		regionEnum.moveNext();
	}
} 
catch (errorMsg) 
{
	MessageBox.Show(errorMsg, "Error", MessageBoxButtons.OK, 
					MessageBoxIcon.Error);
}

/*
 * Finds the marker at the timecode position.
 * If no marker is found it returns null
 */
function FindMarkerAt(time : Timecode) : Marker 
{
	var markerEnum = new Enumerator(Vegas.Project.Markers);
	while (!markerEnum.atEnd()) 
	{
		var marker : Marker = Marker(markerEnum.item());
		// test to see if the timecode is equal
		if (0 == marker.Position.CompareTo(time)) 
		{
			return marker;
		}
		// optimise: if we past the time stop looking.
		if (1 == marker.Position.CompareTo(time)) 
		{
			return null;
		}
		markerEnum.moveNext();
	}
	return null;
}
