/**
* Sample render segments TEST #2
* Revision Date: 2-18-2003
* By: Edward Troxel with corrections by SonicPJM
* with various segments taken from other scripts!
**/

import System;
// import System.Collections;
import System.Text;
import System.IO;
// import System.Drawing;
import System.Windows.Forms;
import System.Object;
import Sony.Vegas;

// here are some default variables for the GUI.
//Path names must use "\\" to indicate a standard path "\"
//so, defaultBasePath refers to D:\renders\

var defaultBasePath = "D:\\renders\\";

// set this to true if you want to allow files to be overwritten
var overwriteExistingFiles = false;

try {
  var SubClipNum = 1;
  var renderStart = new Timecode();
  var totalLength = Vegas.Project.Length;
  var renderLength = new Timecode(4000 * 60); // 4 minutes
// 1000 ms = 1 second so 4000 ms = 4 seconds so 4000 * 60 = 4 minutes.
// (or 1000 * 60 = 1 minute * 4 = 4 minutes)
// 00:04:00:00 could also be used to indicate 4 minutes


  while (renderStart < totalLength) {
    if ((renderLength + renderStart) > totalLength) {
        renderLength = totalLength - renderStart;
    }

    // MessageBox.Show("Render From: " + renderStart + " For Length: " + renderLength);

    var renderer = FindRenderer(/Video for Windows/);
    if (null == renderer)
        throw "failed to find renderer";

    var template = FindRenderTemplate(renderer, /NTSC DV/);
    if (null == template)
        throw "failed to find template";

    DoRender(defaultBasePath + "test" + SubClipNum + ".AVI", renderer, template, renderStart, renderLength);

    renderStart = renderStart + renderLength;
//    renderStart++; // advance one frame
    SubClipNum = SubClipNum + 1;


  }

} catch (e) {
  if (!e.skipMessageBox)
  MessageBox.Show(e);
}



// perform the render. The Render method returns a member of the
// RenderStatus enumeration. If it is anything other than OK, exit
// the loops. This will throw an error message string if the render
// does not complete successfully.
function DoRender(fileName, rndr, rndrTemplate, start, length) {
  // make sure the file does not already exist
  if (!overwriteExistingFiles && File.Exists(fileName)) {
      throw "File already exists: " + fileName;
  }

  // perform the render. The Render method returns
  // a member of the RenderStatus enumeration. If
  // it is anything other than OK, exit the loops.
  var status = Vegas.Render(fileName, rndrTemplate, start, length);

  // if the render completed successfully, just return
  if (status == RenderStatus.Complete)
      return;

  // if the user canceled, throw out a special message that won't be
  // displayed.
  if (status == RenderStatus.Canceled) {
      var cancelMsg = new String("User canceled");
      cancelMsg.skipMessageBox = true;
      throw cancelMsg;
  }

  // if the render failed, throw out a detailed error message.
  var msg : StringBuilder = new StringBuilder("Render failed:\n");
  msg.Append("\n file name: ");
  msg.Append(fileName);
  msg.Append("\n Renderer: ");
  msg.Append(rndr.FileTypeName);
  msg.Append("\n Template: ");
  msg.Append(rndrTemplate.Name);
  msg.Append("\n Start Time: ");
  msg.Append(start.ToString());
  msg.Append("\n Length: ");
  msg.Append(length.ToString());
  throw msg;
}



function FindRenderer(rendererRegExp : RegExp) : Renderer {
  var rendererEnum : Enumerator = new Enumerator(Vegas.Renderers);
  while (!rendererEnum.atEnd()) {
    var renderer : Renderer = Renderer(rendererEnum.item());
    if (null != renderer.FileTypeName.match(rendererRegExp)) {
        return renderer;
    }
    rendererEnum.moveNext();
  }
  return null;
}

function FindRenderTemplate(renderer : Renderer, templateRegExp : RegExp) : RenderTemplate {
  var templateEnum : Enumerator = new Enumerator(renderer.Templates);
  while (!templateEnum.atEnd()) {
    var renderTemplate : RenderTemplate = RenderTemplate(templateEnum.item());
    if (null != renderTemplate.Name.match(templateRegExp)) {
        return renderTemplate;
    }
    templateEnum.moveNext();
  }
  return null;
}


