/** 
* PURPOSE OF THIS SCRIPT:
*
* Select event at cursor, and de-select all other events.
*
* A video track must be selected. If an audio track is selected, nothing happens.
* If the track beneath the video track contains audio, the audio event in that track 
* that lies beneath the cursor will also be selected.
*
* Copyright  John Meyer 2004
* Written: September 23, 2004
*
**/ 

import System; 
import System.IO; 
import System.Windows.Forms; 
import Sony.Vegas; 


try { 

    //Global declarations
    var dStart : Double;
    var dLength : Double;
    var dCursor : Double;
    var trackEnum : Enumerator; 
    var evnt : TrackEvent;
    var CurrentEvnt : TrackEvent; 
 
    var track = FindSelectedTrack();                // Use this function to find the first selected track.  
    var eventEnum = new Enumerator(track.Events);

    if (track.IsVideo()) {                          // Proceed only if selected track is video track.

      if ( SelectEventAtCursor() ) {                // Function that selects events under cursor.

        // Get set to look at track directly below the video track.
        trackEnum.moveNext();                       // Go to next track.

        if (!trackEnum.atEnd()) {                   // Only proceed if there is a track below the video track.
          track = Track(trackEnum.item());          // When doing the first track (above), these two lines were executed
          eventEnum = new Enumerator(track.Events); // in the FindSelectedTrack() function.
          if (track.IsAudio()) {                    // Only trim the event if this is an audio track.
            SelectEventAtCursor();
          }    
        }
      }
    }
//  Vegas.Cursor = CurrentEvnt.Start;  // Enable this line to move cursor to start of selected event.
    Vegas.UpdateUI(); 

} catch (e) { 
  MessageBox.Show(e); 
} 

// End of main program



// Beginning of functions

function FindSelectedTrack() : Track {
  trackEnum = new Enumerator(Vegas.Project.Tracks);
  while (!trackEnum.atEnd()) {
    var track : Track = Track(trackEnum.item());

    if (track.Selected) {
      return track;
    }
    trackEnum.moveNext();
  }
  return null;
}


/** 
*
* The following function finds the event on the selected track 
* that lies under the cursor. It also deselects all other events. 
*
**/

function SelectEventAtCursor() {

  var EventFound : boolean = false;        // Function returns false if no video media under cursor.

  dCursor = Vegas.Cursor.ToMilliseconds(); // Remember the cursor position.

  //Go through each event on the track.

  while (!eventEnum.atEnd()) {
    evnt = TrackEvent(eventEnum.item());
    evnt.Selected = false;                 // De-select the event

    // Get the event's start and length timecode, in milliseconds.
    dStart = evnt.Start.ToMilliseconds();
    dLength = evnt.Length.ToMilliseconds();


/**
*     If the cursor timecode is between the beginning and end of the 
*     event timecodes, then select the event.
**/ 

    if ( (dCursor >= dStart) && ( dCursor < (dLength + dStart) ) ) {
      evnt.Selected = true;                // Select this event.
      EventFound = true;
      CurrentEvnt = evnt;
    }
    eventEnum.moveNext();                  // Go to next event on this timeline.

  } 
return EventFound;
}
