import System.Windows.Forms;
import System.Collections;
import System.Reflection;
import System.IO;
import Microsoft.Win32;
import Sony.Vegas;

/*
 * Script to backup/restore Vegas 5 layouts and import to other PC.
 * More information, see http://www.triton.ch/dust/vegas/layouts.html
 */

var Version = "0.12";

// using undocumented features, the script should only be run on tested
// Vegas versions!
var VegasVersion1 = "Version 5.0a (Build 134)"

// Check version and invoke GUI
try
{
  if (Vegas.Version != VegasVersion1 &&
      MessageBox.Show("This script is only tested with " + VegasVersion1 +
          ", you got " + Vegas.Version + ". continue anyway (on your own risk!)?",
          "Wrong Version!",MessageBoxButtons.YesNo) == "No")
                throw("");
  var dialog = new layoutsDialog();
  dialog.ShowDialog();
}
catch (e)
{if (e != "") MessageBox.Show(e);}

/*
 * GUI
 */

class layoutsDialog extends Form
{
  var metrics; // Registry tree where Vegas keeps layouts
  var layoutsList : ListBox; // layout-set selection list
  var textBox     : TextBox; // layout-set name field (save-as/copy-to)
  var layoutsLabel, nameLabel : Label;

  // Registry tree where Vegas 5 stores its layouts
  function getMetricsKey()
  {
    var rk = Registry.CurrentUser;
    rk = rk.CreateSubKey("Software");
    rk = rk.CreateSubKey("Sony Media Software");
    rk = rk.CreateSubKey("Vegas");
    rk = rk.CreateSubKey("5.0");
    rk = rk.CreateSubKey("Metrics");
    return rk;
  }

  // Registry tree where the script backups Vegas layout-sets
  function getLayoutsTopkey()
  {
    var rk = Registry.CurrentUser;
    rk = rk.CreateSubKey("Software");
    rk = rk.CreateSubKey("VegasScripts");
    rk = rk.CreateSubKey("Layouts");
    return rk;
  }

  // GUI helpers: return selected/entered layout-set name (or "")
  function returnSelected():String
  {
    var name:String = "";
    try {name = layoutsList.SelectedItems[0];}
    catch(e) {}
    if (name==null || name=="")
    {
      MessageBox.Show("You must select name in the left list");
      return "";
    }
    return name;
  }

  function returnText():String
  {
    var name:String = textBox.Text;
    if (name==null || name=="")
    {
      MessageBox.Show("You must enter a layout name in the bottom text line");
      return "";
    }
    return name;
  }

  // GUI helper for updating layout-set selection list (after save, etc)
  function refreshNames()
  {
    layoutsList.BeginUpdate();
    layoutsList.Items.Clear();
    var names = getLayoutsTopkey().GetSubKeyNames();
    for (var i in names)
      layoutsList.Items.Add(names[i]);
    layoutsList.EndUpdate();
  }

  // registry helpers for GUI for saving, loading and copying layout-sets
  function copyLayouts(src:RegistryKey, dst:RegistryKey)
  {
    for (var i=110; i<120; i++)
      try{dst.SetValue("B"+i,src.GetValue("B"+i,""));} catch(e){}
  }

  function saveLayouts(name:String)
  {
    if (name==null || name=="") return;
    var rk = getLayoutsTopkey();
    if (System.Array.IndexOf(rk.GetSubKeyNames(),name)>=0 &&
        MessageBox.Show("Layout-set " + name + " already exists. Overwrite?",
          "Overwrite?",MessageBoxButtons.YesNo) == "No")
                return;
    copyLayouts(metrics,rk.CreateSubKey(name));
    refreshNames();
  }

  function loadLayouts(name:String): Boolean
  {
    if (name==null || name=="") return false;;
    copyLayouts(getLayoutsTopkey().CreateSubKey(name),metrics);
    return true;
  }

  /*
   * GUI action buttons (implement main actions), all inherited from Button
   */

  class SaveAsButton extends Button
  {
    protected function OnClick(e:System.EventArgs)
    {saveLayouts(returnText());}
  }

  class SaveButton extends Button
  {
    protected function OnClick(e:System.EventArgs)
    {saveLayouts(returnSelected());}
  }

  class DeleteButton extends Button
  {
    protected function OnClick(e:System.EventArgs)
    {
      var name = returnSelected();
      if (MessageBox.Show("Are you sure to delete Layout-set " + name + "?",
          "Delete?",MessageBoxButtons.YesNo) == "No")
                return;
      if (name != "") getLayoutsTopkey().DeleteSubKey(name);
      refreshNames();
    }
  }

  class CopyButton extends Button
  {
    protected function OnClick(e:System.EventArgs)
    {
      var nameFrom = returnSelected();
      var nameTo = returnText();
      if (nameFrom == "" || nameTo == "" || nameFrom == nameTo) return;
      var rk = getLayoutsTopkey();
      if (System.Array.IndexOf(rk.GetSubKeyNames(),nameTo)>=0 &&
          MessageBox.Show("Layout-set " + nameTo + " already exists. Overwrite?",
            "Overwrite?",MessageBoxButtons.YesNo) == "No")
              return;
      copyLayouts(rk.CreateSubKey(nameFrom),rk.CreateSubKey(nameTo));
      refreshNames();
    }
  }

  class ResetButton extends Button
  {
    protected function OnClick(e:System.EventArgs)
    {
      for (var i=110; i<120; i++)
        try{metrics.DeleteValue("B"+i);} catch(e) {}
      dialog.DialogResult = "OK"; // leave GUI after loading
    }
  }

  class LoadButton extends Button
  {
    protected function OnClick(e:System.EventArgs)
    {
      if (loadLayouts(returnSelected()))
        dialog.DialogResult = "OK"; // leave GUI after loading
    }
  }

  class GetNameButton extends Button // "V" helper button
  {
    protected function OnClick(e:System.EventArgs)
    {
      var name = returnSelected();
      if (name != "") textBox.Text = name;
    }
  }

  /*
   * Constructor
   */
  function layoutsDialog() {
    metrics = getMetricsKey(); // Find location where Vegas keeps its layouts

    this.Text = "Save and Restore Layouts v" + Version;
    this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
    this.MaximizeBox = false;
    this.StartPosition = FormStartPosition.CenterScreen;
    this.Width = 600; this.Height = 350;

    var titleBarHeight = this.Height - this.ClientSize.Height;
    var buttonWidth = 250;

    // Layout-set selection list
    layoutsLabel = new Label();
    layoutsLabel.AutoSize = true;
    layoutsLabel.Text = "Select layout set:";
    layoutsLabel.Top=10;
    layoutsLabel.Left=10;
    Controls.Add(layoutsLabel);

    layoutsList = new ListBox();
    layoutsList.Sorted = true;
    layoutsList.Size = new System.Drawing.Size(250, 230);
    layoutsList.Location = new System.Drawing.Point(10,30);
    layoutsList.SelectionMode = SelectionMode.One;
    Controls.Add(layoutsList);

    refreshNames();

    // Layout-set name field and helper button ("V")
    nameLabel = new Label();
    nameLabel.AutoSize = true;
    nameLabel.Text = "Enter name (save-as and copy-to):";
    nameLabel.Left=10;
    nameLabel.Top=layoutsList.Bottom+4;
    Controls.Add(nameLabel);

    var getNameButton = new GetNameButton();
    getNameButton.Text = "V";
    getNameButton.Left = nameLabel.Right + 4;
    getNameButton.Top = layoutsList.Bottom+4;
    getNameButton.Width = 20;
    getNameButton.Height = getNameButton.Font.Height + 12;
    Controls.Add(getNameButton);

    textBox = new TextBox();
    textBox.Multiline = false;
    textBox.AcceptsReturn = false;
    textBox.AcceptsTab = false;
    textBox.Width = 250;
    textBox.Location = new System.Drawing.Point(10,getNameButton.Bottom+10);
    Controls.Add(textBox);

    // Action buttons
    var saveButton = new SaveButton();
    saveButton.Text = "Save (to selected)";
    saveButton.Left = layoutsList.Right+4;
    saveButton.Top = layoutsList.Top;
    saveButton.Width = buttonWidth;
    saveButton.Height = saveButton.Font.Height + 12;
    Controls.Add(saveButton);

    var saveAsButton = new SaveAsButton();
    saveAsButton.Text = "Save As";
    saveAsButton.Left = layoutsList.Right+4;
    saveAsButton.Top = textBox.Top;
    saveAsButton.Width = buttonWidth;
    saveAsButton.Height = saveAsButton.Font.Height + 12;
    Controls.Add(saveAsButton);

    var deleteButton = new DeleteButton();
    deleteButton.Text = "Delete (selected)";
    deleteButton.Left = layoutsList.Right+4;
    deleteButton.Top = saveButton.Bottom+4;
    deleteButton.Width = buttonWidth;
    deleteButton.Height = deleteButton.Font.Height + 12;
    Controls.Add(deleteButton);

    var copyButton = new CopyButton();
    copyButton.Text = "Copy (selected) to (text below)";
    copyButton.Left = layoutsList.Right+4;
    copyButton.Top = deleteButton.Bottom+4;
    copyButton.Width = buttonWidth;
    copyButton.Height = copyButton.Font.Height + 12;
    Controls.Add(copyButton);

    var resetButton = new ResetButton();
    resetButton.Text = "Reset Vegas to default layouts";
    resetButton.Left = layoutsList.Right+4;
    resetButton.Top = copyButton.Bottom+4;
    resetButton.Width = buttonWidth;
    resetButton.Height = resetButton.Font.Height + 12;
    Controls.Add(resetButton);

    var loadButton = new LoadButton();
    loadButton.Text = "Load layouts (from selected) <CR/ENTER>";
    loadButton.Left = layoutsList.Right+4;
    loadButton.Top = resetButton.Bottom+12;
    loadButton.Width = buttonWidth;
    loadButton.Height = loadButton.Font.Height + 12;
    AcceptButton = loadButton;
    loadButton.DialogResult = System.Windows.Forms.DialogResult.OK;
    Controls.Add(loadButton);

    var cancelButton = new Button();
    cancelButton.Text = "Close <ESC>";
    cancelButton.Left = layoutsList.Right+4;
    cancelButton.Height = cancelButton.Font.Height + 12;
    cancelButton.Top = saveAsButton.Top-4-cancelButton.Height;
    cancelButton.Width = buttonWidth;
    cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
    CancelButton = cancelButton;
    Controls.Add(cancelButton);


    // Size adjustment
    this.Width = deleteButton.Right+10;
    this.ClientSize.Height = cancelButton.Bottom;
    if (cancelButton.Bottom > this.ClientSize.Height)
      this.ClientSize.Height = cancelButton.Bottom;

    layoutsList.Focus();
  }
}
