/**

Objective:
==========

Script to generate *.chp file from Vegas timeline markers, which can then be imported into 
DVD Maestro as chapter points.

Note:
=====
1)	The DVDMaestro chapter file must have extension *.chp, eg. "myfile.chp"

History:
========
10/12/2003 WL	v1.0.  Creation.
1/1/2004 WL		v1.1
				-	Modified to match ruler format with video format.  Required for *.stl and *.chp.
**/

//----------------------------------------------------------------------------------------
import System;
import System.Text;
import System.IO;
import System.Drawing;
import System.Windows.Forms;
import Sony.Vegas;

//----------------------------------------------------------------------------------------
//
// Variables
//
var desDir = "F:\\home\\dv\\apps\\spruce\\dvdmaestro\\chp";
var srcMpgFname = "*.chp";
var desExt = ".chp";
var desFullFname = desDir + Path.DirectorySeparatorChar + srcMpgFname;

var formatMsg = "unknown";
var originalProjectRuler = Vegas.Project.Ruler.Format;

//----------------------------------------------------------------------------------------
function initVar() {
	var frameRate = Vegas.Project.Video.FrameRate;

	if ( frameRate == 25 ) {
		formatMsg = "PAL, 25fps";
//		MessageBox.Show(formatMsg);
		Vegas.Project.Ruler.Format = RulerFormat.SmpteEBU;
	}
	else {
		formatMsg = "NTSC, 29.97fps, TC=non-drop-frame";
//		MessageBox.Show(formatMsg);
		Vegas.Project.Ruler.Format = RulerFormat.SmpteNonDrop;
	}
	return null;
}

//----------------------------------------------------------------------------------------
// Button subclass that shows a save file dialog when clicked

class BrowseButton extends Button {
    var myResultBox = null;

    function BrowseButton(resultBox) {
        myResultBox = resultBox;
    }

    protected override function OnClick(e : EventArgs) {
        var saveFileDialog = new SaveFileDialog();
		saveFileDialog.Filter = "DVDMaestro Chapter File (*.chp)|*.chp|All Files (*.*)|*.*";
		saveFileDialog.DefaultExt = desExt;
        saveFileDialog.CheckPathExists = true;
		saveFileDialog.CheckFileExists = false;
		saveFileDialog.AddExtension = false;
        if (null != myResultBox) {
            var filename = myResultBox.Text;
            var initialDir = Path.GetDirectoryName(filename);
            if (Directory.Exists(initialDir)) {
                saveFileDialog.InitialDirectory = initialDir;
            }
            saveFileDialog.FileName = Path.GetFileNameWithoutExtension(filename);
//			saveFileDialog.FileName = Path.GetFileName(filename);
        }

        if ( System.Windows.Forms.DialogResult.OK == saveFileDialog.ShowDialog() ) {
            if ( null != myResultBox ) {
				if ( Path.GetExtension(saveFileDialog.FileName) != desExt ) {
					saveFileDialog.FileName = Path.GetFileNameWithoutExtension(saveFileDialog.FileName);
					saveFileDialog.FileName += desExt;
				}
				myResultBox.Text = Path.GetFullPath(saveFileDialog.FileName);
            }
        }
    }
}

//----------------------------------------------------------------------------------------
// Form subclass that is the dialog box for this script

class getFnameDialog extends Form {
    var browseButton;
    var fileNameBox;
	var noticeBox;

    function getFnameDialog(baseFileName) {

        this.Text = "Create DVDMaestro chapter file using timeline markers";
        this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
        this.MaximizeBox = false;
        this.StartPosition = FormStartPosition.CenterScreen;
        this.Width = 580;

        var buttonWidth = 80;

		fileNameBox = addTextControl("DVDMaestro chapter file", 6, 480, 10, baseFileName);
		noticeBox = addTextLabel("Caution: must use extension *.chp, eg. myfile.chp\n", 6, fileNameBox.Bottom+5);

        browseButton = new BrowseButton(fileNameBox);
        browseButton.Left = fileNameBox.Right + 4;
        browseButton.Top = fileNameBox.Top - 2;
        browseButton.Width = buttonWidth;
        browseButton.Height = browseButton.Font.Height + 12;
        browseButton.Text = "Browse...";
        Controls.Add(browseButton);

        var buttonTop = noticeBox.Bottom + 16;

        var okButton = new Button();
        okButton.Text = "OK";
        okButton.Left = this.Width - (2*(buttonWidth+10));
        okButton.Top = buttonTop;
        okButton.Width = buttonWidth;
        okButton.Height = okButton.Font.Height + 12;
        okButton.DialogResult = System.Windows.Forms.DialogResult.OK;
        AcceptButton = okButton;
        Controls.Add(okButton);

        var cancelButton = new Button();
        cancelButton.Text = "Cancel";
        cancelButton.Left = this.Width - (1*(buttonWidth+10));
        cancelButton.Top = buttonTop;
        cancelButton.Height = cancelButton.Font.Height + 12;
        cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
        CancelButton = cancelButton;
        Controls.Add(cancelButton);

        var titleHeight = this.Height - this.ClientSize.Height;
        this.Height = titleHeight + okButton.Bottom + 8;
    }

	function addTextLabel(labelName, left, top) {
		var label = new Label();

		label.AutoSize = true;
		label.Text = labelName;
		label.Left = left;
		label.Top = top + 4;
		Controls.Add(label);
		return label;
	}

	function addTextControl(labelName, left, width, top, defaultValue) {
		var label = new Label();
		label.AutoSize = true;
		label.Text = labelName + ":";
		label.Left = left;
		label.Top = top + 4;
		Controls.Add(label);

		var textbox = new TextBox();
		textbox.Multiline = false;
		textbox.Left = label.Right;
		textbox.Top = top;
		textbox.Width = width - (label.Width);
		textbox.Text = defaultValue;
		Controls.Add(textbox);

		return textbox;
	}
}

//----------------------------------------------------------------------------------------
function openCHP(desDir, srcMpgFname) : StreamWriter {

	if ( !Directory.Exists(desDir) ) {
//		Directory.CreateDirectory(desDir);
		throw "Directory does not exist:\n\n" + desDir;
	}
	var swr = File.CreateText(desFullFname);
	return swr;
}

//----------------------------------------------------------------------------------------
function	closeCHP(swr) {

	swr.Close();
	return null;
}

//----------------------------------------------------------------------------------------
function	writeCHP(swr, markerTC, markerCnt) {

	var counter : int = 0;

	swr.WriteLine( "$Spruce_Iframe_List" );
	swr.WriteLine( "" );

	for (var i : int = 0; i < markerCnt; i++) {
		swr.WriteLine( markerTC[i] );
	}

	return null;
}

//----------------------------------------------------------------------------------------
function	makeDVDMaestroCHP(mrkEnum) {

	var markerCnt : int = 0;
	var markerTC = new Array();
//	var markerLabel = new Array();
	var nowMarker;

	while ( !mrkEnum.atEnd() ) {
		nowMarker = mrkEnum.item();
		var nowMarkPos = Marker(nowMarker).Position;
		markerTC[markerCnt] = nowMarkPos.ToString();
//		markerLabel[markerCnt] = Marker(nowMarker).Label;
		markerCnt++;
		mrkEnum.moveNext();
	}

	if ( markerCnt == 0 )
		throw "Error: no markers defined on Vegas timeline";

	var swr = openCHP(desDir, srcMpgFname);
	writeCHP(swr, markerTC, markerCnt);
	closeCHP(swr);

	return null;
}

//----------------------------------------------------------------------------------------
function findSelectedTrack() : Track {
	var trackEnum = new Enumerator(Vegas.Project.Tracks);

	while (!trackEnum.atEnd()) {
		var track : Track = Track(trackEnum.item());
		if (track.Selected) {
			return track;
		}
		trackEnum.moveNext();
	}
	return null;
}

//----------------------------------------------------------------------------------------
try {

	initVar();

	// Show the script's dialog box.
	var dialog = new getFnameDialog(srcMpgFname);
	var dialogResult = dialog.ShowDialog();

    // if the OK button was pressed...
    if ( System.Windows.Forms.DialogResult.OK == dialogResult ) {

//
// Also need to check extension here in case user bypassed browse button.
//
		desFullFname = Path.GetFullPath(dialog.fileNameBox.Text);
		if ( Path.GetExtension(desFullFname) != desExt )
				desFullFname += desExt;
		desDir = Path.GetDirectoryName(desFullFname);
		srcMpgFname = Path.GetFileName(desFullFname);

//		MessageBox.Show(desDir.ToString() + "\n" + srcMpgFname.ToString() + "\n" + desFullFname.ToString());

		var track = findSelectedTrack();
		if ( null == track )
			throw "Error: no selected track";

		var mrkEnum = new Enumerator(Vegas.Project.Markers);
		makeDVDMaestroCHP(mrkEnum);

		MessageBox.Show("Done.\n\nFormat:	" + formatMsg + "\nFile:	" + desFullFname);
	}

} catch (e) { 
  MessageBox.Show(e); 
} 

